suburb

# XMLRésuméLibrary: User Guide

subjects | Element Reference | suffix

## Name

suburb — A name of a suburb

## Synopsis

### Content Model

    (#PCDATA)

### Attributes

Name | Type | Default
--- | --- | ---
id | ID | None
targets | CDATA | None

## Description

The `suburb` element contains the name of a suburb, as used by a postal service to deliver mail.

### Parents

`suburb` may be contained in these elements: `address`

### Attributes

`id`

  A string used to uniquely identify a suburb. The suburb may then be referred to by this identifier.

## See Also

`city`, `prefecture`, `ward`.

-->

## Examples

Example 12. A New Zealand Address

    <address>
      <street>236 Majoribanks Street</street>
      <suburb>Mount Victoria</suburb>
      <city>Wellington</city>
      <postalCode>6001</postalCode>
      <country>New Zealand</country>
    </address>

subjects | Element Reference | suffix